@@ -4,21 +4,22 @@ import logging
 import os
 import posixpath
 import shlex
+import signal
 from collections import namedtuple
 from dataclasses import asdict
-import signal
 
 import click
 from click.exceptions import MissingParameter, UsageError
 from pykdebugparser.pykdebugparser import PyKdebugParser
-from pymobiledevice3.services.dvt.instruments.screenshot import Screenshot
 from termcolor import colored
 
 import pymobiledevice3
 from pymobiledevice3.cli.cli_common import print_json, Command, default_json_encoder
 from pymobiledevice3.exceptions import DvtDirListError, ExtractingStackshotError
 from pymobiledevice3.lockdown import LockdownClient
+from pymobiledevice3.services.accessibilityaudit import AccessibilityAudit
 from pymobiledevice3.services.debugserver_applist import DebugServerAppList
+from pymobiledevice3.services.dtfetchsymbols import DtFetchSymbols
 from pymobiledevice3.services.dvt.dvt_secure_socket_proxy import DvtSecureSocketProxyService
 from pymobiledevice3.services.dvt.instruments.activity_trace_tap import ActivityTraceTap, decode_message_format
 from pymobiledevice3.services.dvt.instruments.application_listing import ApplicationListing
@@ -30,12 +31,11 @@ from pymobiledevice3.services.dvt.instruments.graphics import Graphics
 from pymobiledevice3.services.dvt.instruments.network_monitor import NetworkMonitor, ConnectionDetectionEvent
 from pymobiledevice3.services.dvt.instruments.notifications import Notifications
 from pymobiledevice3.services.dvt.instruments.process_control import ProcessControl
+from pymobiledevice3.services.dvt.instruments.screenshot import Screenshot
 from pymobiledevice3.services.dvt.instruments.sysmontap import Sysmontap
-from pymobiledevice3.services.accessibilityaudit import AccessibilityAudit
 from pymobiledevice3.services.os_trace import OsTraceService
 from pymobiledevice3.services.remote_server import RemoteServer
 from pymobiledevice3.services.screenshot import ScreenshotService
-from pymobiledevice3.services.dtfetchsymbols import DtFetchSymbols
 from pymobiledevice3.services.simulate_location import DtSimulateLocation
 from pymobiledevice3.tcp_forwarder import TcpForwarder
 
@@ -146,19 +146,18 @@ def pkill(lockdown: LockdownClient, expression):
 
 @dvt.command('launch', cls=Command)
 @click.argument('arguments', type=click.STRING)
-@click.option('--kill-existing/--no-kill-existing', default=True)
-@click.option('--suspended', is_flag=True)
-def launch(lockdown: LockdownClient, arguments: str, kill_existing: bool, suspended: bool):
-    """
-    Launch a process.
-    :param lockdown: Lockdown client.
-    :param arguments: Arguments of process to launch, the first argument is the bundle id.
-    :param kill_existing: Whether to kill an existing instance of this process.
-    :param suspended: Same as WaitForDebugger.
-    """
+@click.option('--kill-existing/--no-kill-existing', default=True,
+              help='Whether to kill an existing instance of this process')
+@click.option('--suspended', is_flag=True, help='Same as WaitForDebugger')
+@click.option('--env', multiple=True, type=click.Tuple((str, str)),
+              help='Environment variables to pass to process given as a list of key value')
+def launch(lockdown: LockdownClient, arguments: str, kill_existing: bool, suspended: bool, env: tuple):
+    """ Launch a process. """
     with DvtSecureSocketProxyService(lockdown=lockdown) as dvt:
         parsed_arguments = shlex.split(arguments)
-        pid = ProcessControl(dvt).launch(parsed_arguments[0], parsed_arguments[1:], kill_existing, suspended)
+        pid = ProcessControl(dvt).launch(bundle_id=parsed_arguments[0], arguments=parsed_arguments[1:],
+                                         kill_existing=kill_existing, start_suspended=suspended,
+                                         environment=dict(env))
         print(f'Process launched with pid {pid}')
 
 
