@@ -165,7 +165,7 @@ class CrashReport:
 
         result += click.style(f'{self.incident_id} {self.timestamp}\n\n', fg='cyan')
 
-        if self.bug_type not in ('109', '309', '327', '385', ):
+        if self.bug_type not in ('109', '309', '327', '385'):
             # these crashes aren't crash dumps
             return result
 
@@ -229,7 +229,6 @@ class CrashReports:
         :param entry: File or Folder to pull.
         :param erase: Whether to erase the original file from the CrashReports directory.
         """
-        Path(out).mkdir(exist_ok=True, parents=True)
 
         def log(src, dst):
             self.logger.info(f'{src} --> {dst}')
@@ -272,3 +271,30 @@ class CrashReports:
                     yield crash_report_raw
                 else:
                     yield crash_report
+
+    def get_new_sysdiagnose(self, out: str, erase: bool = True):
+        """
+        Monitor the creation of a newly created sysdiagnose archive and pull it
+        :param out: filename
+        :param erase: remove after pulling
+        """
+        filename = None
+
+        for syslog_entry in OsTraceService(lockdown=self.lockdown).syslog():
+            if (posixpath.basename(syslog_entry.filename) != 'sysdiagnose') or \
+                    (posixpath.basename(syslog_entry.image_name) != 'sysdiagnose'):
+                # filter only sysdianose lines
+                continue
+
+            message = syslog_entry.message
+
+            if message.startswith('SDArchive: Successfully created tar at '):
+                self.logger.info('sysdiagnose creation has begun')
+
+            if message.startswith('Results written to '):
+                filename = message.split()[-1].replace('IN_PROGRESS_', '').replace(
+                    '/var/mobile/Library/Logs/CrashReporter/', '/')
+                break
+
+        self.afc.wait_exists(filename)
+        self.pull(out, entry=filename, erase=erase)
